OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Επαφές",
    "Download" : "Λήψη",
    "Delete Addressbook" : "Διαγραφή Βιβλίου Διευθύνσεων",
    "Share with users or groups" : "Διαμοιρασμός με χρήστες ή ομάδες",
    "Delete" : "Διαγραφή",
    "can edit" : "δυνατότητα επεξεργασίας",
    "Address book name" : "Όνομα βιβλίου διευθύνσεων",
    "Import" : "Εισαγωγή",
    "The selected image is too big (max 1MB)" : "Η επιλεγμένη εικόνα είναι πολύ μεγάλη (max 1MB)",
    "No contacts in here" : "Δεν υπάρχουν επαφές εδώ",
    "Name" : "Όνομα",
    "Organization" : "Οργανισμός",
    "Title" : "Τίτλος",
    "Add field ..." : "Προσθήκη πεδίου...",
    "No search result for {query}" : "Δεν βρέθηκε αποτέλεσμα αναζήτησης για {query}",
    "_%n contact_::_%n contacts_" : ["%n επαφή","%n επαφές"],
    "Post office box" : "Ταχυδρομική θυρίδα",
    "Postal code" : "Ταχυδρομικός Κωδικός",
    "City" : "Πόλη",
    "State or province" : "Νομός ή περιφέρεια",
    "Country" : "Χώρα",
    "Address" : "Διεύθυνση",
    "(new group)" : "(νέα ομάδα)",
    "Last name" : "Επώνυμο",
    "First name" : "Όνομα",
    "Additional names" : "Επιπλέον ονόματα",
    "Prefix" : "Πρόθεμα",
    "Suffix" : "Κατάληξη",
    "All contacts" : "Όλες οι επαφές",
    "Not grouped" : "Οχι ομαδοποιημένα",
    "New contact" : "Νέα επαφή",
    "{addressbook} shared by {owner}" : "Το {addressbook} διαμοιράστηκε από τον/την {owner}",
    "No contacts in file. Only VCard files are allowed." : "Δεν υπάρχουν επαφές σε αρχείο. Μόνο VCard αρχεία επιτρέπονται.",
    "Nickname" : "Παρατσούκλι",
    "Detailed name" : "Λεπτομερές όνομα",
    "Notes" : "Σημειώσεις",
    "Website" : "Ιστοσελίδα",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Σπίτι",
    "Work" : "Εργασία",
    "Other" : "Άλλο",
    "Groups" : "Ομάδες",
    "Birthday" : "Γενέθλια",
    "Date of death" : "Ημερομηνία θανάτου",
    "Email" : "Ηλ. ταχυδρομείο",
    "Instant messaging" : "Άμεσα μηνύματα",
    "Phone" : "Τηλέφωνο",
    "Mobile" : "Κινητό",
    "Fax" : "Φαξ",
    "Fax home" : "Φαξ σπίτι",
    "Fax work" : "Φαξ εργασία",
    "Pager" : "Βομβητής",
    "Voice" : "Ομιλία",
    "Social network" : "Κοινωνικό δίκτυο",
    "Settings" : "Ρυθμίσεις"
},
"nplurals=2; plural=(n != 1);");
